/**
 * @fileoverview Every href attribute must check its value contains protocol or not
 * @author Kathiresan
 */
'use strict';

//------------------------------------------------------------------------------
// Rule Definition
//------------------------------------------------------------------------------

var ERR_MSG_NOT_CHECKED = 'Please call security method';
module.exports = {
  meta: {
    docs: {
      description:
        'Every href attribute must check its value contains protocol or not',
      category: 'Security Mistake',
      recommended: true
    },
    fixable: null,
    schema: [
      // fill in your schema
    ]
  },

  create: function(context) {
    return {
      JSXOpeningElement: function(node) {
        let status = true;
        if (node.name.name !== 'a') {
          return;
        }
        if (node.attributes.length > 0) {
          node.attributes.map(attr => {
            const isHref =
              attr.type === 'JSXAttribute' && attr.name.name === 'href';
            if (attr.value) {
              if (attr.value.expression) {
                if (isHref && attr.value.expression.type !== 'CallExpression') {
                  status = false;
                }
              }
            }
          });
          if (!status) {
            context.report({ node: node, message: ERR_MSG_NOT_CHECKED });
          }
        }
      }
    };
  }
};
